@@ -40,6 +40,7 @@ class ItemProperties:
     """
     id: int
     name: str
+    last_updated: str
     incomplete: bool
     members: bool
     tradeable: Optional[bool]
@@ -67,7 +68,6 @@ class ItemProperties:
     icon: str
     wiki_name: Optional[str]
     wiki_url: Optional[str]
-    wiki_exchange: Optional[str]
     equipment: Optional[ItemEquipment] = None
     weapon: Optional[ItemWeapon] = None
 
